"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import prodvana.proto.prodvana.common_config.env_pb2
import prodvana.proto.prodvana.common_config.kubernetes_config_pb2
import prodvana.proto.prodvana.common_config.parameters_pb2
import prodvana.proto.prodvana.common_config.program_pb2
import prodvana.proto.prodvana.common_config.rollback_pb2
import prodvana.proto.prodvana.common_config.task_pb2
import prodvana.proto.prodvana.labels.labels_pb2
import prodvana.proto.prodvana.runtimes.extensions.fetch_pb2
import prodvana.proto.prodvana.runtimes.runtimes_config_pb2
import prodvana.proto.prodvana.volumes.volumes_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ClusterType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ClusterTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ClusterType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _ClusterType.ValueType  # 0
    K8S: _ClusterType.ValueType  # 1
    ECS: _ClusterType.ValueType  # 2
    """TODO(naphat) remove, this is legacy ecs implementation not based on runtime extension"""
    FAKE: _ClusterType.ValueType  # 3
    EXTENSION: _ClusterType.ValueType  # 4
    TERRAFORM_RUNNER: _ClusterType.ValueType  # 5
    PULUMI_RUNNER: _ClusterType.ValueType  # 6
    AWS_ECS: _ClusterType.ValueType  # 7
    GOOGLE_CLOUD_RUN: _ClusterType.ValueType  # 8
    FLY: _ClusterType.ValueType  # 9

class ClusterType(_ClusterType, metaclass=_ClusterTypeEnumTypeWrapper): ...

UNKNOWN: ClusterType.ValueType  # 0
K8S: ClusterType.ValueType  # 1
ECS: ClusterType.ValueType  # 2
"""TODO(naphat) remove, this is legacy ecs implementation not based on runtime extension"""
FAKE: ClusterType.ValueType  # 3
EXTENSION: ClusterType.ValueType  # 4
TERRAFORM_RUNNER: ClusterType.ValueType  # 5
PULUMI_RUNNER: ClusterType.ValueType  # 6
AWS_ECS: ClusterType.ValueType  # 7
GOOGLE_CLOUD_RUN: ClusterType.ValueType  # 8
FLY: ClusterType.ValueType  # 9
global___ClusterType = ClusterType

class _ExtensionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ExtensionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ExtensionType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    GENERIC: _ExtensionType.ValueType  # 0
    TERRAFORM: _ExtensionType.ValueType  # 1
    PULUMI: _ExtensionType.ValueType  # 2
    AWS_ECS_EXTENSION: _ExtensionType.ValueType  # 3
    GOOGLE_CLOUD_RUN_EXTENSION: _ExtensionType.ValueType  # 4
    FLY_EXTENSION: _ExtensionType.ValueType  # 5

class ExtensionType(_ExtensionType, metaclass=_ExtensionTypeEnumTypeWrapper): ...

GENERIC: ExtensionType.ValueType  # 0
TERRAFORM: ExtensionType.ValueType  # 1
PULUMI: ExtensionType.ValueType  # 2
AWS_ECS_EXTENSION: ExtensionType.ValueType  # 3
GOOGLE_CLOUD_RUN_EXTENSION: ExtensionType.ValueType  # 4
FLY_EXTENSION: ExtensionType.ValueType  # 5
global___ExtensionType = ExtensionType

class ClusterAuth(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class ECSAuth(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ACCESS_KEY_FIELD_NUMBER: builtins.int
        SECRET_KEY_FIELD_NUMBER: builtins.int
        REGION_FIELD_NUMBER: builtins.int
        ASSUME_ROLE_ARN_FIELD_NUMBER: builtins.int
        CLUSTER_ARN_FIELD_NUMBER: builtins.int
        access_key: builtins.str
        secret_key: builtins.str
        region: builtins.str
        assume_role_arn: builtins.str
        cluster_arn: builtins.str
        def __init__(
            self,
            *,
            access_key: builtins.str = ...,
            secret_key: builtins.str = ...,
            region: builtins.str = ...,
            assume_role_arn: builtins.str = ...,
            cluster_arn: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["access_key", b"access_key", "assume_role_arn", b"assume_role_arn", "cluster_arn", b"cluster_arn", "region", b"region", "secret_key", b"secret_key"]) -> None: ...

    class K8sAuth(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class AgentEnvEntry(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            KEY_FIELD_NUMBER: builtins.int
            VALUE_FIELD_NUMBER: builtins.int
            key: builtins.str
            value: builtins.str
            def __init__(
                self,
                *,
                key: builtins.str = ...,
                value: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

        AGENT_ENV_FIELD_NUMBER: builtins.int
        AGENT_EXTERNALLY_MANAGED_FIELD_NUMBER: builtins.int
        @property
        def agent_env(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
        agent_externally_managed: builtins.bool
        """The Prodvana agent lifecycle is handled by the user -- Prodvana will not install or update the agent."""
        def __init__(
            self,
            *,
            agent_env: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
            agent_externally_managed: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["agent_env", b"agent_env", "agent_externally_managed", b"agent_externally_managed"]) -> None: ...

    ECS_FIELD_NUMBER: builtins.int
    K8S_FIELD_NUMBER: builtins.int
    @property
    def ecs(self) -> global___ClusterAuth.ECSAuth: ...
    @property
    def k8s(self) -> global___ClusterAuth.K8sAuth: ...
    def __init__(
        self,
        *,
        ecs: global___ClusterAuth.ECSAuth | None = ...,
        k8s: global___ClusterAuth.K8sAuth | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth_oneof", b"auth_oneof", "ecs", b"ecs", "k8s", b"k8s"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_oneof", b"auth_oneof", "ecs", b"ecs", "k8s", b"k8s"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth_oneof", b"auth_oneof"]) -> typing_extensions.Literal["ecs", "k8s"] | None: ...

global___ClusterAuth = ClusterAuth

class Cluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    LAST_HEARTBEAT_TIMESTAMP_FIELD_NUMBER: builtins.int
    name: builtins.str
    cluster_id: builtins.str
    @property
    def auth(self) -> global___ClusterAuth: ...
    type: global___ClusterType.ValueType
    @property
    def config(self) -> global___ClusterConfig: ...
    @property
    def last_heartbeat_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        auth: global___ClusterAuth | None = ...,
        type: global___ClusterType.ValueType = ...,
        config: global___ClusterConfig | None = ...,
        last_heartbeat_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "config", b"config", "last_heartbeat_timestamp", b"last_heartbeat_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "cluster_id", b"cluster_id", "config", b"config", "last_heartbeat_timestamp", b"last_heartbeat_timestamp", "name", b"name", "type", b"type"]) -> None: ...

global___Cluster = Cluster

class FakeClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class CrashingProgramPatterns(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        IMAGE_REGEX_FIELD_NUMBER: builtins.int
        CMD_REGEX_FIELD_NUMBER: builtins.int
        LOG_OUTPUT_FIELD_NUMBER: builtins.int
        image_regex: builtins.str
        cmd_regex: builtins.str
        log_output: builtins.str
        def __init__(
            self,
            *,
            image_regex: builtins.str = ...,
            cmd_regex: builtins.str = ...,
            log_output: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["cmd_regex", b"cmd_regex", "image_regex", b"image_regex", "log_output", b"log_output"]) -> None: ...

    CRASHING_PROGRAMS_FIELD_NUMBER: builtins.int
    @property
    def crashing_programs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FakeClusterConfig.CrashingProgramPatterns]: ...
    def __init__(
        self,
        *,
        crashing_programs: collections.abc.Iterable[global___FakeClusterConfig.CrashingProgramPatterns] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["crashing_programs", b"crashing_programs"]) -> None: ...

global___FakeClusterConfig = FakeClusterConfig

class RetryPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_INTERVAL_FIELD_NUMBER: builtins.int
    MAX_INTERVAL_FIELD_NUMBER: builtins.int
    MAX_ATTEMPTS_FIELD_NUMBER: builtins.int
    @property
    def base_interval(self) -> google.protobuf.duration_pb2.Duration: ...
    @property
    def max_interval(self) -> google.protobuf.duration_pb2.Duration: ...
    max_attempts: builtins.int
    """<= 0 means no limit on retries"""
    def __init__(
        self,
        *,
        base_interval: google.protobuf.duration_pb2.Duration | None = ...,
        max_interval: google.protobuf.duration_pb2.Duration | None = ...,
        max_attempts: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base_interval", b"base_interval", "max_interval", b"max_interval"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_interval", b"base_interval", "max_attempts", b"max_attempts", "max_interval", b"max_interval"]) -> None: ...

global___RetryPolicy = RetryPolicy

class ExtensionFetchCommand(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.common_config.env_pb2.EnvValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.common_config.env_pb2.EnvValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TASK_CONFIG_FIELD_NUMBER: builtins.int
    KUBERNETES_CONFIG_FIELD_NUMBER: builtins.int
    POLL_INTERVAL_FIELD_NUMBER: builtins.int
    STEADY_STATE_POLL_INTERVAL_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    RETRY_POLICY_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    FETCH_MODE_FIELD_NUMBER: builtins.int
    @property
    def task_config(self) -> prodvana.proto.prodvana.common_config.task_pb2.TaskConfig: ...
    @property
    def kubernetes_config(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig: ...
    @property
    def poll_interval(self) -> google.protobuf.duration_pb2.Duration:
        """customize intervals instead of using Prodvana default
        only used for fetch
        how often to run command after it succeeds
        """
    @property
    def steady_state_poll_interval(self) -> google.protobuf.duration_pb2.Duration:
        """how often to fetch when in steady state (after the extension has converged)"""
    @property
    def timeout(self) -> google.protobuf.duration_pb2.Duration:
        """deprecated, not used"""
    @property
    def retry_policy(self) -> global___RetryPolicy:
        """retry policy for unexpected failures (this means exits other than 0 or 2 when fetch_mode = EXIT_CODE, or other than 0 for STRUCTURED_OUTPUT).
        if not set, regular, non-steady-state poll interval is used for fetches.
        """
    @property
    def env(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue]:
        """optional env variables to inject and override from exec_config"""
    fetch_mode: prodvana.proto.prodvana.runtimes.extensions.fetch_pb2.FetchMode.ValueType
    """how to interpret the output of the command"""
    def __init__(
        self,
        *,
        task_config: prodvana.proto.prodvana.common_config.task_pb2.TaskConfig | None = ...,
        kubernetes_config: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig | None = ...,
        poll_interval: google.protobuf.duration_pb2.Duration | None = ...,
        steady_state_poll_interval: google.protobuf.duration_pb2.Duration | None = ...,
        timeout: google.protobuf.duration_pb2.Duration | None = ...,
        retry_policy: global___RetryPolicy | None = ...,
        env: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue] | None = ...,
        fetch_mode: prodvana.proto.prodvana.runtimes.extensions.fetch_pb2.FetchMode.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["exec_config", b"exec_config", "kubernetes_config", b"kubernetes_config", "poll_interval", b"poll_interval", "retry_policy", b"retry_policy", "steady_state_poll_interval", b"steady_state_poll_interval", "task_config", b"task_config", "timeout", b"timeout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["env", b"env", "exec_config", b"exec_config", "fetch_mode", b"fetch_mode", "kubernetes_config", b"kubernetes_config", "poll_interval", b"poll_interval", "retry_policy", b"retry_policy", "steady_state_poll_interval", b"steady_state_poll_interval", "task_config", b"task_config", "timeout", b"timeout"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["exec_config", b"exec_config"]) -> typing_extensions.Literal["task_config", "kubernetes_config"] | None: ...

global___ExtensionFetchCommand = ExtensionFetchCommand

class ExtensionGetInfoCommand(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.common_config.env_pb2.EnvValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.common_config.env_pb2.EnvValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TASK_CONFIG_FIELD_NUMBER: builtins.int
    KUBERNETES_CONFIG_FIELD_NUMBER: builtins.int
    POLL_INTERVAL_FIELD_NUMBER: builtins.int
    RETRY_POLICY_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    TEST_ONLY_DO_NOT_REQUIRE_PVN_WRAPPER_FIELD_NUMBER: builtins.int
    @property
    def task_config(self) -> prodvana.proto.prodvana.common_config.task_pb2.TaskConfig: ...
    @property
    def kubernetes_config(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig: ...
    @property
    def poll_interval(self) -> google.protobuf.duration_pb2.Duration:
        """customize intervals instead of using Prodvana default
        defaults to 5 minutes
        """
    @property
    def retry_policy(self) -> global___RetryPolicy:
        """retry policy for unexpected failures.
        defaults to fast retrying after 30s then backing off to 10 minutes
        """
    @property
    def env(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue]:
        """optional env variables to inject and override from exec_config"""
    test_only_do_not_require_pvn_wrapper: builtins.bool
    """exposed for internal testing. do not set"""
    def __init__(
        self,
        *,
        task_config: prodvana.proto.prodvana.common_config.task_pb2.TaskConfig | None = ...,
        kubernetes_config: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig | None = ...,
        poll_interval: google.protobuf.duration_pb2.Duration | None = ...,
        retry_policy: global___RetryPolicy | None = ...,
        env: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue] | None = ...,
        test_only_do_not_require_pvn_wrapper: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["exec_config", b"exec_config", "kubernetes_config", b"kubernetes_config", "poll_interval", b"poll_interval", "retry_policy", b"retry_policy", "task_config", b"task_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["env", b"env", "exec_config", b"exec_config", "kubernetes_config", b"kubernetes_config", "poll_interval", b"poll_interval", "retry_policy", b"retry_policy", "task_config", b"task_config", "test_only_do_not_require_pvn_wrapper", b"test_only_do_not_require_pvn_wrapper"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["exec_config", b"exec_config"]) -> typing_extensions.Literal["task_config", "kubernetes_config"] | None: ...

global___ExtensionGetInfoCommand = ExtensionGetInfoCommand

class ExtensionApplyCommand(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.common_config.env_pb2.EnvValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.common_config.env_pb2.EnvValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TASK_CONFIG_FIELD_NUMBER: builtins.int
    KUBERNETES_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    RETRY_POLICY_FIELD_NUMBER: builtins.int
    RETRYABLE_EXIT_CODES_FIELD_NUMBER: builtins.int
    MAX_CONCURRENCY_FIELD_NUMBER: builtins.int
    @property
    def task_config(self) -> prodvana.proto.prodvana.common_config.task_pb2.TaskConfig: ...
    @property
    def kubernetes_config(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig: ...
    @property
    def timeout(self) -> google.protobuf.duration_pb2.Duration:
        """deprecated, not used"""
    @property
    def env(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue]:
        """optional env variables to inject and override from exec_config"""
    @property
    def retry_policy(self) -> global___RetryPolicy:
        """used in conjunction with retryable_exit_codes, defaults to the convergence grace period"""
    @property
    def retryable_exit_codes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """if set and the apply command returns these exit codes, retry the command without marking the result as failing."""
    max_concurrency: builtins.int
    """optional, if set, do not run more than this many apply commands concurrently"""
    def __init__(
        self,
        *,
        task_config: prodvana.proto.prodvana.common_config.task_pb2.TaskConfig | None = ...,
        kubernetes_config: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig | None = ...,
        timeout: google.protobuf.duration_pb2.Duration | None = ...,
        env: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue] | None = ...,
        retry_policy: global___RetryPolicy | None = ...,
        retryable_exit_codes: collections.abc.Iterable[builtins.int] | None = ...,
        max_concurrency: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["exec_config", b"exec_config", "kubernetes_config", b"kubernetes_config", "retry_policy", b"retry_policy", "task_config", b"task_config", "timeout", b"timeout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["env", b"env", "exec_config", b"exec_config", "kubernetes_config", b"kubernetes_config", "max_concurrency", b"max_concurrency", "retry_policy", b"retry_policy", "retryable_exit_codes", b"retryable_exit_codes", "task_config", b"task_config", "timeout", b"timeout"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["exec_config", b"exec_config"]) -> typing_extensions.Literal["task_config", "kubernetes_config"] | None: ...

global___ExtensionApplyCommand = ExtensionApplyCommand

class ExtensionClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLY_FIELD_NUMBER: builtins.int
    FETCH_FIELD_NUMBER: builtins.int
    DEBUG_FIELD_NUMBER: builtins.int
    GET_INFO_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    PROXY_RUNTIME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    REQUIRE_APPROVAL_BEFORE_APPLY_FIELD_NUMBER: builtins.int
    CONVERGENCE_GRACE_PERIOD_FIELD_NUMBER: builtins.int
    @property
    def apply(self) -> global___ExtensionApplyCommand: ...
    @property
    def fetch(self) -> global___ExtensionFetchCommand: ...
    @property
    def debug(self) -> global___ExtensionGetInfoCommand:
        """deprecated, set this as get_info instead"""
    @property
    def get_info(self) -> global___ExtensionGetInfoCommand: ...
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterDefinition]: ...
    @property
    def proxy_runtime(self) -> prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig: ...
    type: global___ExtensionType.ValueType
    require_approval_before_apply: builtins.bool
    """Apply is potentially dangerous - require approval before each apply"""
    @property
    def convergence_grace_period(self) -> google.protobuf.duration_pb2.Duration:
        """How long after apply ran the first time should it be restarted if the service still has not converged.
        This duration is computed from the *start* of apply run.
        Defaults to 10m.
        next tag: 10
        """
    def __init__(
        self,
        *,
        apply: global___ExtensionApplyCommand | None = ...,
        fetch: global___ExtensionFetchCommand | None = ...,
        debug: global___ExtensionGetInfoCommand | None = ...,
        get_info: global___ExtensionGetInfoCommand | None = ...,
        parameters: collections.abc.Iterable[prodvana.proto.prodvana.common_config.parameters_pb2.ParameterDefinition] | None = ...,
        proxy_runtime: prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig | None = ...,
        type: global___ExtensionType.ValueType = ...,
        require_approval_before_apply: builtins.bool = ...,
        convergence_grace_period: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["apply", b"apply", "convergence_grace_period", b"convergence_grace_period", "debug", b"debug", "fetch", b"fetch", "get_info", b"get_info", "proxy_runtime", b"proxy_runtime"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["apply", b"apply", "convergence_grace_period", b"convergence_grace_period", "debug", b"debug", "fetch", b"fetch", "get_info", b"get_info", "parameters", b"parameters", "proxy_runtime", b"proxy_runtime", "require_approval_before_apply", b"require_approval_before_apply", "type", b"type"]) -> None: ...

global___ExtensionClusterConfig = ExtensionClusterConfig

class CompiledExtensionCommand(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class CompiledExtensionCommandExec(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TASK_CONFIG_FIELD_NUMBER: builtins.int
        KUBERNETES_CONFIG_FIELD_NUMBER: builtins.int
        @property
        def task_config(self) -> prodvana.proto.prodvana.common_config.task_pb2.TaskConfig: ...
        @property
        def kubernetes_config(self) -> prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig: ...
        def __init__(
            self,
            *,
            task_config: prodvana.proto.prodvana.common_config.task_pb2.TaskConfig | None = ...,
            kubernetes_config: prodvana.proto.prodvana.common_config.kubernetes_config_pb2.KubernetesConfig | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["exec_config", b"exec_config", "kubernetes_config", b"kubernetes_config", "task_config", b"task_config"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["exec_config", b"exec_config", "kubernetes_config", b"kubernetes_config", "task_config", b"task_config"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["exec_config", b"exec_config"]) -> typing_extensions.Literal["task_config", "kubernetes_config"] | None: ...

    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.common_config.env_pb2.EnvValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.common_config.env_pb2.EnvValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_PREFIX_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    RUNTIME_EXECUTION_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    name_prefix: builtins.str
    @property
    def command(self) -> global___CompiledExtensionCommand.CompiledExtensionCommandExec:
        """weird nesting for compatibility reasons, from before fetch and apply definitions were split"""
    @property
    def runtime_execution(self) -> prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig: ...
    @property
    def env(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue]: ...
    def __init__(
        self,
        *,
        name_prefix: builtins.str = ...,
        command: global___CompiledExtensionCommand.CompiledExtensionCommandExec | None = ...,
        runtime_execution: prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig | None = ...,
        env: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["command", b"command", "runtime_execution", b"runtime_execution"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["command", b"command", "env", b"env", "name_prefix", b"name_prefix", "runtime_execution", b"runtime_execution"]) -> None: ...

global___CompiledExtensionCommand = CompiledExtensionCommand

class IacRunnerCommand(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CMD_FIELD_NUMBER: builtins.int
    cmd: builtins.str
    def __init__(
        self,
        *,
        cmd: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cmd", b"cmd"]) -> None: ...

global___IacRunnerCommand = IacRunnerCommand

class TerraformRunnerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.common_config.env_pb2.EnvValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.common_config.env_pb2.EnvValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    PROXY_RUNTIME_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    VOLUMES_FIELD_NUMBER: builtins.int
    PRE_RUN_FIELD_NUMBER: builtins.int
    POLL_INTERVAL_FIELD_NUMBER: builtins.int
    STEADY_STATE_POLL_INTERVAL_FIELD_NUMBER: builtins.int
    REQUIRE_APPROVAL_BEFORE_APPLY_FIELD_NUMBER: builtins.int
    CONVERGENCE_GRACE_PERIOD_FIELD_NUMBER: builtins.int
    FETCH_RETRY_POLICY_FIELD_NUMBER: builtins.int
    APPLY_RETRY_POLICY_FIELD_NUMBER: builtins.int
    DISABLE_DRIFT_DETECTION_FIELD_NUMBER: builtins.int
    TASK_RESOURCES_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    @property
    def proxy_runtime(self) -> prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig: ...
    @property
    def env(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue]:
        """optional env variables to pass to terraform commands, can be useful for passing secrets"""
    @property
    def volumes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.volumes.volumes_pb2.Volume]:
        """optional volumes to mount into terraform containers"""
    @property
    def pre_run(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IacRunnerCommand]:
        """commands that must run before terraform can run, e.g. gcloud auth login"""
    @property
    def poll_interval(self) -> google.protobuf.duration_pb2.Duration:
        """Poll interval for terraform plan when not converged, defaults to 5 minutes. Polling takes a lock on terraform state file, so increase this if you run terraform plan locally often."""
    @property
    def steady_state_poll_interval(self) -> google.protobuf.duration_pb2.Duration:
        """Poll interval for terraform plan in steady state (after it has converged), defaults to 1 hour. During steady state, polling is used for drift detection.
        This is the min duration of time for which drift not being detected is OK.
        """
    require_approval_before_apply: builtins.bool
    """Require approval before every apply operation - this is on top of any release channel-level approvals."""
    @property
    def convergence_grace_period(self) -> google.protobuf.duration_pb2.Duration: ...
    @property
    def fetch_retry_policy(self) -> global___RetryPolicy:
        """override default retry policy. Default is min = 1m, max = 15m."""
    @property
    def apply_retry_policy(self) -> global___RetryPolicy:
        """override apply retry policy. Default is min = 30s, max = 5m."""
    disable_drift_detection: builtins.bool
    """Skip drift detection. This is useful for faster convergence on updates, but can lead to drift going undetected.
    When enabled, steady state polling is turned off.
    NOTE: Only supported in Pulumi today.
    """
    @property
    def task_resources(self) -> prodvana.proto.prodvana.common_config.program_pb2.ResourceRequirements:
        """Resource constraints for the  runner's Fetch and Apply commands."""
    service_account: builtins.str
    """optionally override what service account is used for terraform"""
    def __init__(
        self,
        *,
        proxy_runtime: prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig | None = ...,
        env: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.common_config.env_pb2.EnvValue] | None = ...,
        volumes: collections.abc.Iterable[prodvana.proto.prodvana.volumes.volumes_pb2.Volume] | None = ...,
        pre_run: collections.abc.Iterable[global___IacRunnerCommand] | None = ...,
        poll_interval: google.protobuf.duration_pb2.Duration | None = ...,
        steady_state_poll_interval: google.protobuf.duration_pb2.Duration | None = ...,
        require_approval_before_apply: builtins.bool = ...,
        convergence_grace_period: google.protobuf.duration_pb2.Duration | None = ...,
        fetch_retry_policy: global___RetryPolicy | None = ...,
        apply_retry_policy: global___RetryPolicy | None = ...,
        disable_drift_detection: builtins.bool = ...,
        task_resources: prodvana.proto.prodvana.common_config.program_pb2.ResourceRequirements | None = ...,
        service_account: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["apply_retry_policy", b"apply_retry_policy", "convergence_grace_period", b"convergence_grace_period", "fetch_retry_policy", b"fetch_retry_policy", "poll_interval", b"poll_interval", "proxy_runtime", b"proxy_runtime", "steady_state_poll_interval", b"steady_state_poll_interval", "task_resources", b"task_resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["apply_retry_policy", b"apply_retry_policy", "convergence_grace_period", b"convergence_grace_period", "disable_drift_detection", b"disable_drift_detection", "env", b"env", "fetch_retry_policy", b"fetch_retry_policy", "poll_interval", b"poll_interval", "pre_run", b"pre_run", "proxy_runtime", b"proxy_runtime", "require_approval_before_apply", b"require_approval_before_apply", "service_account", b"service_account", "steady_state_poll_interval", b"steady_state_poll_interval", "task_resources", b"task_resources", "volumes", b"volumes"]) -> None: ...

global___TerraformRunnerConfig = TerraformRunnerConfig

class GKEClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_NAME_FIELD_NUMBER: builtins.int
    CLUSTER_LOCATION_FIELD_NUMBER: builtins.int
    CLUSTER_NAME_FIELD_NUMBER: builtins.int
    project_name: builtins.str
    cluster_location: builtins.str
    cluster_name: builtins.str
    def __init__(
        self,
        *,
        project_name: builtins.str = ...,
        cluster_location: builtins.str = ...,
        cluster_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_location", b"cluster_location", "cluster_name", b"cluster_name", "project_name", b"project_name"]) -> None: ...

global___GKEClusterMetadata = GKEClusterMetadata

class ClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GKE_FIELD_NUMBER: builtins.int
    @property
    def gke(self) -> global___GKEClusterMetadata: ...
    def __init__(
        self,
        *,
        gke: global___GKEClusterMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cluster_metadata", b"cluster_metadata", "gke", b"gke"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_metadata", b"cluster_metadata", "gke", b"gke"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["cluster_metadata", b"cluster_metadata"]) -> typing_extensions.Literal["gke"] | None: ...

global___ClusterMetadata = ClusterMetadata

class AwsEcsConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class AccessKey(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        AWS_ACCESS_KEY_ID_FIELD_NUMBER: builtins.int
        AWS_SECRET_ACCESS_KEY_FIELD_NUMBER: builtins.int
        aws_access_key_id: builtins.str
        @property
        def aws_secret_access_key(self) -> prodvana.proto.prodvana.common_config.env_pb2.SecretReferenceValue: ...
        def __init__(
            self,
            *,
            aws_access_key_id: builtins.str = ...,
            aws_secret_access_key: prodvana.proto.prodvana.common_config.env_pb2.SecretReferenceValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["aws_secret_access_key", b"aws_secret_access_key"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["aws_access_key_id", b"aws_access_key_id", "aws_secret_access_key", b"aws_secret_access_key"]) -> None: ...

    class InheritRole(google.protobuf.message.Message):
        """the ProxyRuntime has been configured with an IAM role that has the necessary permissions"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        K8S_SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
        k8s_service_account: builtins.str
        """optional, if the proxy runtime is an EKS cluster you can specify the K8S Service Account to
        use. If not passed, the default service account for the namespace will be used.
        """
        def __init__(
            self,
            *,
            k8s_service_account: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["k8s_service_account", b"k8s_service_account"]) -> None: ...

    PROXY_RUNTIME_FIELD_NUMBER: builtins.int
    ACCESS_KEY_FIELD_NUMBER: builtins.int
    INHERIT_ROLE_FROM_RUNTIME_ENV_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ECS_CLUSTER_FIELD_NUMBER: builtins.int
    @property
    def proxy_runtime(self) -> prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig: ...
    @property
    def access_key(self) -> global___AwsEcsConfig.AccessKey: ...
    @property
    def inherit_role_from_runtime_env(self) -> global___AwsEcsConfig.InheritRole:
        """the ProxyRuntime has been configured with an IAM role that has the necessary permissions
        TODO(naphat) assumeRole support
        """
    region: builtins.str
    ecs_cluster: builtins.str
    def __init__(
        self,
        *,
        proxy_runtime: prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig | None = ...,
        access_key: global___AwsEcsConfig.AccessKey | None = ...,
        inherit_role_from_runtime_env: global___AwsEcsConfig.InheritRole | None = ...,
        region: builtins.str = ...,
        ecs_cluster: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["access_key", b"access_key", "credentials", b"credentials", "inherit_role_from_runtime_env", b"inherit_role_from_runtime_env", "proxy_runtime", b"proxy_runtime"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_key", b"access_key", "credentials", b"credentials", "ecs_cluster", b"ecs_cluster", "inherit_role_from_runtime_env", b"inherit_role_from_runtime_env", "proxy_runtime", b"proxy_runtime", "region", b"region"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["credentials", b"credentials"]) -> typing_extensions.Literal["access_key", "inherit_role_from_runtime_env"] | None: ...

global___AwsEcsConfig = AwsEcsConfig

class GoogleCloudRunConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROXY_RUNTIME_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_JSON_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    @property
    def proxy_runtime(self) -> prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig: ...
    @property
    def service_account_json(self) -> prodvana.proto.prodvana.common_config.env_pb2.SecretReferenceValue:
        """TODO(naphat) support for job service account name"""
    project: builtins.str
    region: builtins.str
    """next tag: 5"""
    def __init__(
        self,
        *,
        proxy_runtime: prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig | None = ...,
        service_account_json: prodvana.proto.prodvana.common_config.env_pb2.SecretReferenceValue | None = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["credentials", b"credentials", "proxy_runtime", b"proxy_runtime", "service_account_json", b"service_account_json"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["credentials", b"credentials", "project", b"project", "proxy_runtime", b"proxy_runtime", "region", b"region", "service_account_json", b"service_account_json"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["credentials", b"credentials"]) -> typing_extensions.Literal["service_account_json"] | None: ...

global___GoogleCloudRunConfig = GoogleCloudRunConfig

class FlyConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROXY_RUNTIME_FIELD_NUMBER: builtins.int
    FLY_API_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def proxy_runtime(self) -> prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig: ...
    @property
    def fly_api_token(self) -> prodvana.proto.prodvana.common_config.env_pb2.SecretReferenceValue: ...
    def __init__(
        self,
        *,
        proxy_runtime: prodvana.proto.prodvana.runtimes.runtimes_config_pb2.RuntimeExecutionConfig | None = ...,
        fly_api_token: prodvana.proto.prodvana.common_config.env_pb2.SecretReferenceValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["credentials", b"credentials", "fly_api_token", b"fly_api_token", "proxy_runtime", b"proxy_runtime"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["credentials", b"credentials", "fly_api_token", b"fly_api_token", "proxy_runtime", b"proxy_runtime"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["credentials", b"credentials"]) -> typing_extensions.Literal["fly_api_token"] | None: ...

global___FlyConfig = FlyConfig

class ClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _CloudProvider:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _CloudProviderEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ClusterConfig._CloudProvider.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: ClusterConfig._CloudProvider.ValueType  # 0
        EKS: ClusterConfig._CloudProvider.ValueType  # 1
        GKE: ClusterConfig._CloudProvider.ValueType  # 2
        AKS: ClusterConfig._CloudProvider.ValueType  # 3
        ONPREM: ClusterConfig._CloudProvider.ValueType  # 4
        OTHER_CLOUD: ClusterConfig._CloudProvider.ValueType  # 5

    class CloudProvider(_CloudProvider, metaclass=_CloudProviderEnumTypeWrapper): ...
    UNKNOWN: ClusterConfig.CloudProvider.ValueType  # 0
    EKS: ClusterConfig.CloudProvider.ValueType  # 1
    GKE: ClusterConfig.CloudProvider.ValueType  # 2
    AKS: ClusterConfig.CloudProvider.ValueType  # 3
    ONPREM: ClusterConfig.CloudProvider.ValueType  # 4
    OTHER_CLOUD: ClusterConfig.CloudProvider.ValueType  # 5

    class Kubecost(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        KUBECOST_NAMESPACE_FIELD_NUMBER: builtins.int
        MANAGED_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        kubecost_namespace: builtins.str
        managed: builtins.bool
        """deprecated"""
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            kubecost_namespace: builtins.str = ...,
            managed: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "kubecost_namespace", b"kubecost_namespace", "managed", b"managed"]) -> None: ...

    class Datadog(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        DATADOG_NAMESPACE_FIELD_NUMBER: builtins.int
        API_KEY_FIELD_NUMBER: builtins.int
        SITE_FIELD_NUMBER: builtins.int
        MANAGED_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        datadog_namespace: builtins.str
        api_key: builtins.str
        site: builtins.str
        managed: builtins.bool
        """deprecated"""
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            datadog_namespace: builtins.str = ...,
            api_key: builtins.str = ...,
            site: builtins.str = ...,
            managed: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["api_key", b"api_key", "datadog_namespace", b"datadog_namespace", "enabled", b"enabled", "managed", b"managed", "site", b"site"]) -> None: ...

    class ALBIngress(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        INGRESS_CLASS_FIELD_NUMBER: builtins.int
        DEFAULT_BALANCER_ATTRIBUTES_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        ingress_class: builtins.str
        @property
        def default_balancer_attributes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Attributes from https://docs.aws.amazon.com/elasticloadbalancing/latest/application/application-load-balancers.html#load-balancer-attributes
            that are added to all Ingresses/LBs created in this runtime.
            """
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            ingress_class: builtins.str = ...,
            default_balancer_attributes: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["default_balancer_attributes", b"default_balancer_attributes", "enabled", b"enabled", "ingress_class", b"ingress_class"]) -> None: ...

    class ArgoRollouts(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class AnalysisTemplate(google.protobuf.message.Message):
            """deprecated"""

            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            class _ArgValue:
                ValueType = typing.NewType("ValueType", builtins.int)
                V: typing_extensions.TypeAlias = ValueType

            class _ArgValueEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ClusterConfig.ArgoRollouts.AnalysisTemplate._ArgValue.ValueType], builtins.type):  # noqa: F821
                DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                UNKNOWN: ClusterConfig.ArgoRollouts.AnalysisTemplate._ArgValue.ValueType  # 0
                SERVICE: ClusterConfig.ArgoRollouts.AnalysisTemplate._ArgValue.ValueType  # 1
                RELEASE_CHANNEL: ClusterConfig.ArgoRollouts.AnalysisTemplate._ArgValue.ValueType  # 2

            class ArgValue(_ArgValue, metaclass=_ArgValueEnumTypeWrapper): ...
            UNKNOWN: ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgValue.ValueType  # 0
            SERVICE: ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgValue.ValueType  # 1
            RELEASE_CHANNEL: ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgValue.ValueType  # 2

            class ArgMappingEntry(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                KEY_FIELD_NUMBER: builtins.int
                VALUE_FIELD_NUMBER: builtins.int
                key: builtins.str
                value: global___ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgValue.ValueType
                def __init__(
                    self,
                    *,
                    key: builtins.str = ...,
                    value: global___ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgValue.ValueType = ...,
                ) -> None: ...
                def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

            NAME_FIELD_NUMBER: builtins.int
            ARG_MAPPING_FIELD_NUMBER: builtins.int
            name: builtins.str
            @property
            def arg_mapping(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, global___ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgValue.ValueType]:
                """template argument name to prodvana value to inject"""
            def __init__(
                self,
                *,
                name: builtins.str = ...,
                arg_mapping: collections.abc.Mapping[builtins.str, global___ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgValue.ValueType] | None = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal["arg_mapping", b"arg_mapping", "name", b"name"]) -> None: ...

        ENABLED_FIELD_NUMBER: builtins.int
        TEMPLATES_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        @property
        def templates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterConfig.ArgoRollouts.AnalysisTemplate]:
            """deprecated"""
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            templates: collections.abc.Iterable[global___ClusterConfig.ArgoRollouts.AnalysisTemplate] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "templates", b"templates"]) -> None: ...

    class GKEIngress(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        CONTAINER_NATIVE_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        container_native: builtins.bool
        """Enables container native load balancing, allowing GCP LBs to target k8s pods directly.
        See: https://cloud.google.com/kubernetes-engine/docs/how-to/container-native-load-balancing
        """
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            container_native: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["container_native", b"container_native", "enabled", b"enabled"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    KUBECOST_FIELD_NUMBER: builtins.int
    DATADOG_FIELD_NUMBER: builtins.int
    ALB_INGRESS_FIELD_NUMBER: builtins.int
    ARGO_ROLLOUTS_FIELD_NUMBER: builtins.int
    GKE_INGRESS_FIELD_NUMBER: builtins.int
    SELF_MANAGED_GKE_INGRESS_FIELD_NUMBER: builtins.int
    CLOUD_PROVIDER_FIELD_NUMBER: builtins.int
    DETECTED_CLUSTER_METADATA_FIELD_NUMBER: builtins.int
    USER_SUPPLIED_CLUSTER_METADATA_FIELD_NUMBER: builtins.int
    FAKE_FIELD_NUMBER: builtins.int
    EXTENSION_FIELD_NUMBER: builtins.int
    CUSTOM_FIELD_NUMBER: builtins.int
    TERRAFORM_RUNNER_FIELD_NUMBER: builtins.int
    PULUMI_RUNNER_FIELD_NUMBER: builtins.int
    AWS_ECS_FIELD_NUMBER: builtins.int
    GOOGLE_CLOUD_RUN_FIELD_NUMBER: builtins.int
    FLY_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    AUTO_ROLLBACK_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def kubecost(self) -> global___ClusterConfig.Kubecost: ...
    @property
    def datadog(self) -> global___ClusterConfig.Datadog: ...
    @property
    def alb_ingress(self) -> global___ClusterConfig.ALBIngress: ...
    @property
    def argo_rollouts(self) -> global___ClusterConfig.ArgoRollouts: ...
    @property
    def gke_ingress(self) -> global___ClusterConfig.GKEIngress: ...
    @property
    def self_managed_gke_ingress(self) -> global___ClusterConfig.GKEIngress:
        """Self-Managed GKE Ingress - exposes configuration options for GKE Ingress
        but does not create an ingress object for you
        """
    cloud_provider: global___ClusterConfig.CloudProvider.ValueType
    @property
    def detected_cluster_metadata(self) -> global___ClusterMetadata: ...
    @property
    def user_supplied_cluster_metadata(self) -> global___ClusterMetadata: ...
    @property
    def fake(self) -> global___FakeClusterConfig:
        """only used for fake runtimes"""
    @property
    def extension(self) -> global___ExtensionClusterConfig:
        """deprecated, use custom which means the same thing"""
    @property
    def custom(self) -> global___ExtensionClusterConfig: ...
    @property
    def terraform_runner(self) -> global___TerraformRunnerConfig:
        """terraform runner is a runtime that runs terraform via k8s jobs"""
    @property
    def pulumi_runner(self) -> global___TerraformRunnerConfig:
        """pulumi runner is a runtime that runs pulumi via k8s jobs"""
    @property
    def aws_ecs(self) -> global___AwsEcsConfig: ...
    @property
    def google_cloud_run(self) -> global___GoogleCloudRunConfig: ...
    @property
    def fly(self) -> global___FlyConfig: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.labels.labels_pb2.LabelDefinition]: ...
    @property
    def auto_rollback(self) -> prodvana.proto.prodvana.common_config.rollback_pb2.AutoRollbackConfig: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        kubecost: global___ClusterConfig.Kubecost | None = ...,
        datadog: global___ClusterConfig.Datadog | None = ...,
        alb_ingress: global___ClusterConfig.ALBIngress | None = ...,
        argo_rollouts: global___ClusterConfig.ArgoRollouts | None = ...,
        gke_ingress: global___ClusterConfig.GKEIngress | None = ...,
        self_managed_gke_ingress: global___ClusterConfig.GKEIngress | None = ...,
        cloud_provider: global___ClusterConfig.CloudProvider.ValueType = ...,
        detected_cluster_metadata: global___ClusterMetadata | None = ...,
        user_supplied_cluster_metadata: global___ClusterMetadata | None = ...,
        fake: global___FakeClusterConfig | None = ...,
        extension: global___ExtensionClusterConfig | None = ...,
        custom: global___ExtensionClusterConfig | None = ...,
        terraform_runner: global___TerraformRunnerConfig | None = ...,
        pulumi_runner: global___TerraformRunnerConfig | None = ...,
        aws_ecs: global___AwsEcsConfig | None = ...,
        google_cloud_run: global___GoogleCloudRunConfig | None = ...,
        fly: global___FlyConfig | None = ...,
        labels: collections.abc.Iterable[prodvana.proto.prodvana.labels.labels_pb2.LabelDefinition] | None = ...,
        auto_rollback: prodvana.proto.prodvana.common_config.rollback_pb2.AutoRollbackConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["alb_ingress", b"alb_ingress", "argo_rollouts", b"argo_rollouts", "auto_rollback", b"auto_rollback", "aws_ecs", b"aws_ecs", "cluster_oneof", b"cluster_oneof", "custom", b"custom", "datadog", b"datadog", "detected_cluster_metadata", b"detected_cluster_metadata", "extension", b"extension", "fake", b"fake", "fly", b"fly", "gke_ingress", b"gke_ingress", "google_cloud_run", b"google_cloud_run", "kubecost", b"kubecost", "pulumi_runner", b"pulumi_runner", "self_managed_gke_ingress", b"self_managed_gke_ingress", "terraform_runner", b"terraform_runner", "user_supplied_cluster_metadata", b"user_supplied_cluster_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alb_ingress", b"alb_ingress", "argo_rollouts", b"argo_rollouts", "auto_rollback", b"auto_rollback", "aws_ecs", b"aws_ecs", "cloud_provider", b"cloud_provider", "cluster_oneof", b"cluster_oneof", "custom", b"custom", "datadog", b"datadog", "detected_cluster_metadata", b"detected_cluster_metadata", "extension", b"extension", "fake", b"fake", "fly", b"fly", "gke_ingress", b"gke_ingress", "google_cloud_run", b"google_cloud_run", "kubecost", b"kubecost", "labels", b"labels", "name", b"name", "pulumi_runner", b"pulumi_runner", "self_managed_gke_ingress", b"self_managed_gke_ingress", "terraform_runner", b"terraform_runner", "user_supplied_cluster_metadata", b"user_supplied_cluster_metadata"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["cluster_oneof", b"cluster_oneof"]) -> typing_extensions.Literal["fake", "extension", "custom", "terraform_runner", "pulumi_runner", "aws_ecs", "google_cloud_run", "fly"] | None: ...

global___ClusterConfig = ClusterConfig



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import prodvana.proto.prodvana.environment.clusters_pb2
import prodvana.proto.prodvana.version.source_metadata_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GetClusterAgentApiTokenReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___GetClusterAgentApiTokenReq = GetClusterAgentApiTokenReq

class GetClusterAgentApiTokenResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_TOKEN_FIELD_NUMBER: builtins.int
    api_token: builtins.str
    def __init__(
        self,
        *,
        api_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_token", b"api_token"]) -> None: ...

global___GetClusterAgentApiTokenResp = GetClusterAgentApiTokenResp

class LinkClusterReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    AUTH_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    SOURCE_METADATA_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def auth(self) -> prodvana.proto.prodvana.environment.clusters_pb2.ClusterAuth: ...
    type: prodvana.proto.prodvana.environment.clusters_pb2.ClusterType.ValueType
    @property
    def config(self) -> prodvana.proto.prodvana.environment.clusters_pb2.ClusterConfig: ...
    source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType
    @property
    def source_metadata(self) -> prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        auth: prodvana.proto.prodvana.environment.clusters_pb2.ClusterAuth | None = ...,
        type: prodvana.proto.prodvana.environment.clusters_pb2.ClusterType.ValueType = ...,
        config: prodvana.proto.prodvana.environment.clusters_pb2.ClusterConfig | None = ...,
        source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType = ...,
        source_metadata: prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "config", b"config", "source_metadata", b"source_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "config", b"config", "name", b"name", "source", b"source", "source_metadata", b"source_metadata", "type", b"type"]) -> None: ...

global___LinkClusterReq = LinkClusterReq

class LinkClusterResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    K8S_AGENT_URL_FIELD_NUMBER: builtins.int
    K8S_AGENT_IMAGE_FIELD_NUMBER: builtins.int
    K8S_AGENT_ARGS_FIELD_NUMBER: builtins.int
    K8S_AGENT_API_TOKEN_FIELD_NUMBER: builtins.int
    success: builtins.bool
    """LinkCluster will attempt to talk to the cluster to validate the
    credentials. If it fails, want to communicate back what the failure was.
    """
    msg: builtins.str
    cluster_id: builtins.str
    k8s_agent_url: builtins.str
    """Magic URL to install agent"""
    k8s_agent_image: builtins.str
    """agent details broken out for externally constructing the agent configuration"""
    @property
    def k8s_agent_args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    k8s_agent_api_token: builtins.str
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
        msg: builtins.str = ...,
        cluster_id: builtins.str = ...,
        k8s_agent_url: builtins.str = ...,
        k8s_agent_image: builtins.str = ...,
        k8s_agent_args: collections.abc.Iterable[builtins.str] | None = ...,
        k8s_agent_api_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_id", b"cluster_id", "k8s_agent_api_token", b"k8s_agent_api_token", "k8s_agent_args", b"k8s_agent_args", "k8s_agent_image", b"k8s_agent_image", "k8s_agent_url", b"k8s_agent_url", "msg", b"msg", "success", b"success"]) -> None: ...

global___LinkClusterResp = LinkClusterResp

class RemoveClusterReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """TODO(mike): add an option to remove by cluster_id as well?"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___RemoveClusterReq = RemoveClusterReq

class RemoveClusterResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RemoveClusterResp = RemoveClusterResp

class GetClusterAuthReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___GetClusterAuthReq = GetClusterAuthReq

class GetClusterAuthResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTH_FIELD_NUMBER: builtins.int
    @property
    def auth(self) -> prodvana.proto.prodvana.environment.clusters_pb2.ClusterAuth: ...
    def __init__(
        self,
        *,
        auth: prodvana.proto.prodvana.environment.clusters_pb2.ClusterAuth | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth"]) -> None: ...

global___GetClusterAuthResp = GetClusterAuthResp

class ListClustersReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListClustersReq = ListClustersReq

class ListClustersResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class ClusterInfo(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class EcsInfo(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            REGION_FIELD_NUMBER: builtins.int
            CLUSTER_ARN_FIELD_NUMBER: builtins.int
            region: builtins.str
            cluster_arn: builtins.str
            def __init__(
                self,
                *,
                region: builtins.str = ...,
                cluster_arn: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal["cluster_arn", b"cluster_arn", "region", b"region"]) -> None: ...

        NAME_FIELD_NUMBER: builtins.int
        ID_FIELD_NUMBER: builtins.int
        ENDPOINT_FIELD_NUMBER: builtins.int
        SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
        TYPE_FIELD_NUMBER: builtins.int
        ECS_FIELD_NUMBER: builtins.int
        LAST_HEARTBEAT_TIMESTAMP_FIELD_NUMBER: builtins.int
        CONFIG_FIELD_NUMBER: builtins.int
        AUTH_FIELD_NUMBER: builtins.int
        name: builtins.str
        id: builtins.str
        endpoint: builtins.str
        service_account: builtins.str
        type: prodvana.proto.prodvana.environment.clusters_pb2.ClusterType.ValueType
        @property
        def ecs(self) -> global___ListClustersResp.ClusterInfo.EcsInfo: ...
        @property
        def last_heartbeat_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        @property
        def config(self) -> prodvana.proto.prodvana.environment.clusters_pb2.ClusterConfig: ...
        @property
        def auth(self) -> prodvana.proto.prodvana.environment.clusters_pb2.ClusterAuth: ...
        def __init__(
            self,
            *,
            name: builtins.str = ...,
            id: builtins.str = ...,
            endpoint: builtins.str = ...,
            service_account: builtins.str = ...,
            type: prodvana.proto.prodvana.environment.clusters_pb2.ClusterType.ValueType = ...,
            ecs: global___ListClustersResp.ClusterInfo.EcsInfo | None = ...,
            last_heartbeat_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
            config: prodvana.proto.prodvana.environment.clusters_pb2.ClusterConfig | None = ...,
            auth: prodvana.proto.prodvana.environment.clusters_pb2.ClusterAuth | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["auth", b"auth", "config", b"config", "ecs", b"ecs", "info", b"info", "last_heartbeat_timestamp", b"last_heartbeat_timestamp"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth", "config", b"config", "ecs", b"ecs", "endpoint", b"endpoint", "id", b"id", "info", b"info", "last_heartbeat_timestamp", b"last_heartbeat_timestamp", "name", b"name", "service_account", b"service_account", "type", b"type"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["info", b"info"]) -> typing_extensions.Literal["ecs"] | None: ...

    CLUSTERS_FIELD_NUMBER: builtins.int
    @property
    def clusters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListClustersResp.ClusterInfo]: ...
    def __init__(
        self,
        *,
        clusters: collections.abc.Iterable[global___ListClustersResp.ClusterInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["clusters", b"clusters"]) -> None: ...

global___ListClustersResp = ListClustersResp

class GetClusterReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNTIME_FIELD_NUMBER: builtins.int
    INCLUDE_AUTH_FIELD_NUMBER: builtins.int
    runtime: builtins.str
    """name or id"""
    include_auth: builtins.bool
    def __init__(
        self,
        *,
        runtime: builtins.str = ...,
        include_auth: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["include_auth", b"include_auth", "runtime", b"runtime"]) -> None: ...

global___GetClusterReq = GetClusterReq

class GetClusterResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_FIELD_NUMBER: builtins.int
    @property
    def cluster(self) -> global___ListClustersResp.ClusterInfo: ...
    def __init__(
        self,
        *,
        cluster: global___ListClustersResp.ClusterInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cluster", b"cluster"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster", b"cluster"]) -> None: ...

global___GetClusterResp = GetClusterResp

class ConfigureClusterReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNTIME_NAME_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    SOURCE_METADATA_FIELD_NUMBER: builtins.int
    runtime_name: builtins.str
    @property
    def config(self) -> prodvana.proto.prodvana.environment.clusters_pb2.ClusterConfig: ...
    source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType
    @property
    def source_metadata(self) -> prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata: ...
    def __init__(
        self,
        *,
        runtime_name: builtins.str = ...,
        config: prodvana.proto.prodvana.environment.clusters_pb2.ClusterConfig | None = ...,
        source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType = ...,
        source_metadata: prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config", "source_metadata", b"source_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "runtime_name", b"runtime_name", "source", b"source", "source_metadata", b"source_metadata"]) -> None: ...

global___ConfigureClusterReq = ConfigureClusterReq

class ConfigureClusterResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ConfigureClusterResp = ConfigureClusterResp

class ValidateConfigureClusterResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INPUT_CONFIG_FIELD_NUMBER: builtins.int
    COMPILED_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def input_config(self) -> prodvana.proto.prodvana.environment.clusters_pb2.ClusterConfig: ...
    @property
    def compiled_config(self) -> prodvana.proto.prodvana.environment.clusters_pb2.ClusterConfig: ...
    def __init__(
        self,
        *,
        input_config: prodvana.proto.prodvana.environment.clusters_pb2.ClusterConfig | None = ...,
        compiled_config: prodvana.proto.prodvana.environment.clusters_pb2.ClusterConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "input_config", b"input_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compiled_config", b"compiled_config", "input_config", b"input_config"]) -> None: ...

global___ValidateConfigureClusterResp = ValidateConfigureClusterResp

class GetClusterConfigReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNTIME_NAME_FIELD_NUMBER: builtins.int
    runtime_name: builtins.str
    def __init__(
        self,
        *,
        runtime_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["runtime_name", b"runtime_name"]) -> None: ...

global___GetClusterConfigReq = GetClusterConfigReq

class GetClusterConfigResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> prodvana.proto.prodvana.environment.clusters_pb2.ClusterConfig: ...
    def __init__(
        self,
        *,
        config: prodvana.proto.prodvana.environment.clusters_pb2.ClusterConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config"]) -> None: ...

global___GetClusterConfigResp = GetClusterConfigResp

class DetectClusterConfigReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNTIME_NAME_FIELD_NUMBER: builtins.int
    runtime_name: builtins.str
    def __init__(
        self,
        *,
        runtime_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["runtime_name", b"runtime_name"]) -> None: ...

global___DetectClusterConfigReq = DetectClusterConfigReq

class DetectClusterConfigResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> prodvana.proto.prodvana.environment.clusters_pb2.ClusterConfig: ...
    def __init__(
        self,
        *,
        config: prodvana.proto.prodvana.environment.clusters_pb2.ClusterConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config"]) -> None: ...

global___DetectClusterConfigResp = DetectClusterConfigResp

class GetClusterStatusReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___GetClusterStatusReq = GetClusterStatusReq

class GetClusterStatusResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_HEARTBEAT_TIMESTAMP_FIELD_NUMBER: builtins.int
    @property
    def last_heartbeat_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        last_heartbeat_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_heartbeat_timestamp", b"last_heartbeat_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_heartbeat_timestamp", b"last_heartbeat_timestamp"]) -> None: ...

global___GetClusterStatusResp = GetClusterStatusResp

class PauseClusterReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNTIME_FIELD_NUMBER: builtins.int
    runtime: builtins.str
    """name or id"""
    def __init__(
        self,
        *,
        runtime: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["runtime", b"runtime"]) -> None: ...

global___PauseClusterReq = PauseClusterReq

class PauseClusterResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PauseClusterResp = PauseClusterResp

class ResumeClusterReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNTIME_FIELD_NUMBER: builtins.int
    runtime: builtins.str
    """name or id"""
    def __init__(
        self,
        *,
        runtime: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["runtime", b"runtime"]) -> None: ...

global___ResumeClusterReq = ResumeClusterReq

class ResumeClusterResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ResumeClusterResp = ResumeClusterResp



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import prodvana.proto.prodvana.desired_state.model.desired_state_pb2
import prodvana.proto.prodvana.object.meta_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Status:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Status.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN_STATUS: _Status.ValueType  # 0
    PENDING: _Status.ValueType  # 1
    """Pending means this train entry has never been started and is waiting for dependencies to be met."""
    IN_PROGRESS: _Status.ValueType  # 2
    """Dependencies have been met and this train entry has been promoted."""
    SUCCEEDED: _Status.ValueType  # 3
    """Successfully converged."""
    FAILED: _Status.ValueType  # 4
    """Promoted but failed to converge."""
    SKIPPED: _Status.ValueType  # 5
    """This train entry was skipped - any dependencies on this entry can proceed."""

class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...

UNKNOWN_STATUS: Status.ValueType  # 0
PENDING: Status.ValueType  # 1
"""Pending means this train entry has never been started and is waiting for dependencies to be met."""
IN_PROGRESS: Status.ValueType  # 2
"""Dependencies have been met and this train entry has been promoted."""
SUCCEEDED: Status.ValueType  # 3
"""Successfully converged."""
FAILED: Status.ValueType  # 4
"""Promoted but failed to converge."""
SKIPPED: Status.ValueType  # 5
"""This train entry was skipped - any dependencies on this entry can proceed."""
global___Status = Status

class _Strategy:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _StrategyEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Strategy.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN_STRATEGY: _Strategy.ValueType  # 0
    RELEASE_TRAIN: _Strategy.ValueType  # 2
    MAESTRO_DISABLED: _Strategy.ValueType  # 3
    IMMEDIATE: _Strategy.ValueType  # 4

class Strategy(_Strategy, metaclass=_StrategyEnumTypeWrapper): ...

UNKNOWN_STRATEGY: Strategy.ValueType  # 0
RELEASE_TRAIN: Strategy.ValueType  # 2
MAESTRO_DISABLED: Strategy.ValueType  # 3
IMMEDIATE: Strategy.ValueType  # 4
global___Strategy = Strategy

class MaestroConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STRATEGY_FIELD_NUMBER: builtins.int
    strategy: global___Strategy.ValueType
    def __init__(
        self,
        *,
        strategy: global___Strategy.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["strategy", b"strategy"]) -> None: ...

global___MaestroConfig = MaestroConfig

class MaestroReleaseConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_ID_FIELD_NUMBER: builtins.int
    MAESTRO_CONFIG_FIELD_NUMBER: builtins.int
    INPUT_DESIRED_STATE_FIELD_NUMBER: builtins.int
    COMPILED_DESIRED_STATE_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    SET_DESIRED_STATE_METADATA_FIELD_NUMBER: builtins.int
    @property
    def entity_id(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier: ...
    @property
    def maestro_config(self) -> global___MaestroConfig: ...
    @property
    def input_desired_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def compiled_desired_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def creation_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def set_desired_state_metadata(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.SetDesiredStateMetadata:
        """next tag: 7"""
    def __init__(
        self,
        *,
        entity_id: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier | None = ...,
        maestro_config: global___MaestroConfig | None = ...,
        input_desired_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        compiled_desired_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        creation_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        set_desired_state_metadata: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.SetDesiredStateMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compiled_desired_state", b"compiled_desired_state", "creation_timestamp", b"creation_timestamp", "entity_id", b"entity_id", "input_desired_state", b"input_desired_state", "maestro_config", b"maestro_config", "set_desired_state_metadata", b"set_desired_state_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compiled_desired_state", b"compiled_desired_state", "creation_timestamp", b"creation_timestamp", "entity_id", b"entity_id", "input_desired_state", b"input_desired_state", "maestro_config", b"maestro_config", "set_desired_state_metadata", b"set_desired_state_metadata"]) -> None: ...

global___MaestroReleaseConfig = MaestroReleaseConfig

class MaestroReleaseState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class ReleaseChannelStatusesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: global___Status.ValueType
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___Status.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    class ReleaseChannelStatesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___MaestroReleaseChannelState: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___MaestroReleaseChannelState | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    STATUS_FIELD_NUMBER: builtins.int
    LAST_UPDATE_TIMESTAMP_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_STATUSES_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_STATES_FIELD_NUMBER: builtins.int
    SHARED_ROOT_DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    status: global___Status.ValueType
    @property
    def last_update_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def release_channel_statuses(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, global___Status.ValueType]:
        """status by release channel id. Use release_channel_states instead."""
    @property
    def release_channel_states(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___MaestroReleaseChannelState]: ...
    shared_root_desired_state_id: builtins.str
    def __init__(
        self,
        *,
        status: global___Status.ValueType = ...,
        last_update_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        release_channel_statuses: collections.abc.Mapping[builtins.str, global___Status.ValueType] | None = ...,
        release_channel_states: collections.abc.Mapping[builtins.str, global___MaestroReleaseChannelState] | None = ...,
        shared_root_desired_state_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_update_timestamp", b"last_update_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_update_timestamp", b"last_update_timestamp", "release_channel_states", b"release_channel_states", "release_channel_statuses", b"release_channel_statuses", "shared_root_desired_state_id", b"shared_root_desired_state_id", "status", b"status"]) -> None: ...

global___MaestroReleaseState = MaestroReleaseState

class MaestroReleaseChannelState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    ENTITY_ID_FIELD_NUMBER: builtins.int
    ROOT_DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    status: global___Status.ValueType
    desired_state_id: builtins.str
    entity_id: builtins.str
    root_desired_state_id: builtins.str
    def __init__(
        self,
        *,
        status: global___Status.ValueType = ...,
        desired_state_id: builtins.str = ...,
        entity_id: builtins.str = ...,
        root_desired_state_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desired_state_id", b"desired_state_id", "entity_id", b"entity_id", "root_desired_state_id", b"root_desired_state_id", "status", b"status"]) -> None: ...

global___MaestroReleaseChannelState = MaestroReleaseChannelState

class MaestroRelease(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    META_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    @property
    def meta(self) -> prodvana.proto.prodvana.object.meta_pb2.ObjectMeta: ...
    @property
    def config(self) -> global___MaestroReleaseConfig: ...
    @property
    def state(self) -> global___MaestroReleaseState: ...
    def __init__(
        self,
        *,
        meta: prodvana.proto.prodvana.object.meta_pb2.ObjectMeta | None = ...,
        config: global___MaestroReleaseConfig | None = ...,
        state: global___MaestroReleaseState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config", "meta", b"meta", "state", b"state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "meta", b"meta", "state", b"state"]) -> None: ...

global___MaestroRelease = MaestroRelease



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/protection/builtins.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"prodvana/protection/builtins.proto\x12\x13prodvana.protection\x1a\x17validate/validate.proto\"\x85\x03\n\x1e\x43ommitDenylistProtectionConfig\x12\x1b\n\nrepository\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12U\n\x07\x63ommits\x18\x02 \x03(\x0b\x32\x44.prodvana.protection.CommitDenylistProtectionConfig.CommitDefinition\x1a\xee\x01\n\x10\x43ommitDefinition\x12\x19\n\x06\x63ommit\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x65\n\x05range\x18\x02 \x01(\x0b\x32J.prodvana.protection.CommitDenylistProtectionConfig.CommitDefinition.RangeB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x1a\x43\n\x05Range\x12\x1d\n\x0cstart_commit\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1b\n\nend_commit\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42\x13\n\x0c\x63ommit_oneof\x12\x03\xf8\x42\x01\"G\n\nTimeWindow\x12\x15\n\x04\x64\x61ys\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x16\n\x05hours\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\n\n\x02tz\x18\x03 \x01(\t\"_\n\x1c\x41llowedTimesProtectionConfig\x12?\n\x07windows\x18\x01 \x03(\x0b\x32\x1f.prodvana.protection.TimeWindowB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x42OZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/protectionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.protection.builtins_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/protection'
  _COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION_RANGE.fields_by_name['start_commit']._options = None
  _COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION_RANGE.fields_by_name['start_commit']._serialized_options = b'\372B\004r\002\020\001'
  _COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION_RANGE.fields_by_name['end_commit']._options = None
  _COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION_RANGE.fields_by_name['end_commit']._serialized_options = b'\372B\004r\002\020\001'
  _COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION.oneofs_by_name['commit_oneof']._options = None
  _COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION.oneofs_by_name['commit_oneof']._serialized_options = b'\370B\001'
  _COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION.fields_by_name['commit']._options = None
  _COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION.fields_by_name['commit']._serialized_options = b'\372B\004r\002\020\001'
  _COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION.fields_by_name['range']._options = None
  _COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION.fields_by_name['range']._serialized_options = b'\372B\005\212\001\002\020\001'
  _COMMITDENYLISTPROTECTIONCONFIG.fields_by_name['repository']._options = None
  _COMMITDENYLISTPROTECTIONCONFIG.fields_by_name['repository']._serialized_options = b'\372B\004r\002\020\001'
  _TIMEWINDOW.fields_by_name['days']._options = None
  _TIMEWINDOW.fields_by_name['days']._serialized_options = b'\372B\004r\002\020\001'
  _TIMEWINDOW.fields_by_name['hours']._options = None
  _TIMEWINDOW.fields_by_name['hours']._serialized_options = b'\372B\004r\002\020\001'
  _ALLOWEDTIMESPROTECTIONCONFIG.fields_by_name['windows']._options = None
  _ALLOWEDTIMESPROTECTIONCONFIG.fields_by_name['windows']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _globals['_COMMITDENYLISTPROTECTIONCONFIG']._serialized_start=85
  _globals['_COMMITDENYLISTPROTECTIONCONFIG']._serialized_end=474
  _globals['_COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION']._serialized_start=236
  _globals['_COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION']._serialized_end=474
  _globals['_COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION_RANGE']._serialized_start=386
  _globals['_COMMITDENYLISTPROTECTIONCONFIG_COMMITDEFINITION_RANGE']._serialized_end=453
  _globals['_TIMEWINDOW']._serialized_start=476
  _globals['_TIMEWINDOW']._serialized_end=547
  _globals['_ALLOWEDTIMESPROTECTIONCONFIG']._serialized_start=549
  _globals['_ALLOWEDTIMESPROTECTIONCONFIG']._serialized_end=644
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/program.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.common_config import env_pb2 as prodvana_dot_common__config_dot_env__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$prodvana/common_config/program.proto\x12\x16prodvana.common_config\x1a prodvana/common_config/env.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x17validate/validate.proto\"\xf5\x01\n\nPortConfig\x12\x19\n\x04port\x18\x01 \x01(\x05\x42\x0b\xfa\x42\x08\x1a\x06\x18\xff\xff\x03(\x00\x12 \n\x0btarget_port\x18\x02 \x01(\x05\x42\x0b\xfa\x42\x08\x1a\x06\x18\xff\xff\x03(\x00\x12\x10\n\x08\x65xternal\x18\x03 \x01(\x08\x12=\n\x08protocol\x18\x04 \x01(\x0e\x32+.prodvana.common_config.PortConfig.Protocol\x12\x0b\n\x03tls\x18\x05 \x01(\x08\"L\n\x08Protocol\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04HTTP\x10\x01\x12\t\n\x05HTTP2\x10\x02\x12\x08\n\x04GRPC\x10\x03\x12\x07\n\x03TCP\x10\x04\"\x04\x08\x05\x10\x05*\x05HTTPS\"+\n\x0cResourceList\x12\x0e\n\x06memory\x18\x01 \x01(\t\x12\x0b\n\x03\x63pu\x18\x02 \x01(\t\"\x84\x01\n\x14ResourceRequirements\x12\x36\n\x08requests\x18\x01 \x01(\x0b\x32$.prodvana.common_config.ResourceList\x12\x34\n\x06limits\x18\x02 \x01(\x0b\x32$.prodvana.common_config.ResourceList\"A\n\tHttpProbe\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x19\n\x04port\x18\x02 \x01(\x05\x42\x0b\xfa\x42\x08\x1a\x06\x18\xff\xff\x03 \x00\x12\x0b\n\x03tls\x18\x03 \x01(\x08\"\x1b\n\x08\x43mdProbe\x12\x0f\n\x07\x63ommand\x18\x01 \x03(\t\"3\n\x08TcpProbe\x12\x19\n\x04port\x18\x01 \x01(\x05\x42\x0b\xfa\x42\x08\x1a\x06\x18\xff\xff\x03 \x00\x12\x0c\n\x04host\x18\x02 \x01(\t\"\x8c\x02\n\x0bHealthCheck\x12\x31\n\x04http\x18\x01 \x01(\x0b\x32!.prodvana.common_config.HttpProbeH\x00\x12/\n\x03\x63md\x18\x02 \x01(\x0b\x32 .prodvana.common_config.CmdProbeH\x00\x12/\n\x03tcp\x18\x03 \x01(\x0b\x32 .prodvana.common_config.TcpProbeH\x00\x12(\n\x05\x64\x65lay\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12)\n\x06period\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\x13\n\x0cprobe_config\x12\x03\xf8\x42\x01\"q\n\x11ImageRegistryInfo\x12\x1d\n\x15\x63ontainer_registry_id\x18\x01 \x01(\t\x12\x1a\n\x12\x63ontainer_registry\x18\x02 \x01(\t\x12!\n\x10image_repository\x18\x07 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"w\n\x0cImageDetails\x12J\n\rregistry_info\x18\x01 \x01(\x0b\x32).prodvana.common_config.ImageRegistryInfoB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x1b\n\nidentifier\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\x8c\x05\n\rProgramConfig\x12:\n\x04name\x18\x01 \x01(\tB,\xfa\x42)r\'\x10\x00\x18?2!^[a-z]?([a-z0-9-]*[a-z0-9]){0,1}$\x12\r\n\x05image\x18\x02 \x01(\t\x12\x11\n\timage_tag\x18\x0e \x01(\t\x12\x46\n\x13image_registry_info\x18\t \x01(\x0b\x32).prodvana.common_config.ImageRegistryInfo\x12\x0b\n\x03\x63md\x18\x03 \x03(\t\x12\x12\n\nentrypoint\x18\x04 \x03(\t\x12\x64\n\x03\x65nv\x18\x05 \x03(\x0b\x32..prodvana.common_config.ProgramConfig.EnvEntryB\'\xfa\x42$\x9a\x01!\x18\x01\"\x1dr\x1b\x32\x19^[a-zA-Z_]+[a-zA-Z0-9_]*$\x12?\n\tresources\x18\x06 \x01(\x0b\x32,.prodvana.common_config.ResourceRequirements\x12\x39\n\x0chealth_check\x18\x07 \x01(\x0b\x32#.prodvana.common_config.HealthCheck\x12@\n\x05ports\x18\x08 \x03(\x0b\x32\".prodvana.common_config.PortConfigB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x12\x19\n\x11template_complete\x18\n \x01(\x08\x12\x19\n\x11working_directory\x18\x0f \x01(\t\x1aL\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .prodvana.common_config.EnvValue:\x02\x38\x01J\x04\x08\x0b\x10\x0cR\x06\x63ommit\"\x8a\x03\n\x1ePerReleaseChannelProgramConfig\x12\x39\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$\x12u\n\x03\x65nv\x18\x02 \x03(\x0b\x32?.prodvana.common_config.PerReleaseChannelProgramConfig.EnvEntryB\'\xfa\x42$\x9a\x01!\x18\x01\"\x1dr\x1b\x32\x19^[a-zA-Z_]+[a-zA-Z0-9_]*$\x12\r\n\x05image\x18\x03 \x01(\t\x12\x46\n\x13image_registry_info\x18\x04 \x01(\x0b\x32).prodvana.common_config.ImageRegistryInfo\x12\x11\n\timage_tag\x18\x05 \x01(\t\x1aL\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .prodvana.common_config.EnvValue:\x02\x38\x01\x42RZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.common_config.program_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _PORTCONFIG.fields_by_name['port']._options = None
  _PORTCONFIG.fields_by_name['port']._serialized_options = b'\372B\010\032\006\030\377\377\003(\000'
  _PORTCONFIG.fields_by_name['target_port']._options = None
  _PORTCONFIG.fields_by_name['target_port']._serialized_options = b'\372B\010\032\006\030\377\377\003(\000'
  _HTTPPROBE.fields_by_name['port']._options = None
  _HTTPPROBE.fields_by_name['port']._serialized_options = b'\372B\010\032\006\030\377\377\003 \000'
  _TCPPROBE.fields_by_name['port']._options = None
  _TCPPROBE.fields_by_name['port']._serialized_options = b'\372B\010\032\006\030\377\377\003 \000'
  _HEALTHCHECK.oneofs_by_name['probe_config']._options = None
  _HEALTHCHECK.oneofs_by_name['probe_config']._serialized_options = b'\370B\001'
  _IMAGEREGISTRYINFO.fields_by_name['image_repository']._options = None
  _IMAGEREGISTRYINFO.fields_by_name['image_repository']._serialized_options = b'\372B\004r\002\020\001'
  _IMAGEDETAILS.fields_by_name['registry_info']._options = None
  _IMAGEDETAILS.fields_by_name['registry_info']._serialized_options = b'\372B\005\212\001\002\020\001'
  _IMAGEDETAILS.fields_by_name['identifier']._options = None
  _IMAGEDETAILS.fields_by_name['identifier']._serialized_options = b'\372B\004r\002\020\001'
  _PROGRAMCONFIG_ENVENTRY._options = None
  _PROGRAMCONFIG_ENVENTRY._serialized_options = b'8\001'
  _PROGRAMCONFIG.fields_by_name['name']._options = None
  _PROGRAMCONFIG.fields_by_name['name']._serialized_options = b'\372B)r\'\020\000\030?2!^[a-z]?([a-z0-9-]*[a-z0-9]){0,1}$'
  _PROGRAMCONFIG.fields_by_name['env']._options = None
  _PROGRAMCONFIG.fields_by_name['env']._serialized_options = b'\372B$\232\001!\030\001\"\035r\0332\031^[a-zA-Z_]+[a-zA-Z0-9_]*$'
  _PROGRAMCONFIG.fields_by_name['ports']._options = None
  _PROGRAMCONFIG.fields_by_name['ports']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _PERRELEASECHANNELPROGRAMCONFIG_ENVENTRY._options = None
  _PERRELEASECHANNELPROGRAMCONFIG_ENVENTRY._serialized_options = b'8\001'
  _PERRELEASECHANNELPROGRAMCONFIG.fields_by_name['name']._options = None
  _PERRELEASECHANNELPROGRAMCONFIG.fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$'
  _PERRELEASECHANNELPROGRAMCONFIG.fields_by_name['env']._options = None
  _PERRELEASECHANNELPROGRAMCONFIG.fields_by_name['env']._serialized_options = b'\372B$\232\001!\030\001\"\035r\0332\031^[a-zA-Z_]+[a-zA-Z0-9_]*$'
  _globals['_PORTCONFIG']._serialized_start=156
  _globals['_PORTCONFIG']._serialized_end=401
  _globals['_PORTCONFIG_PROTOCOL']._serialized_start=325
  _globals['_PORTCONFIG_PROTOCOL']._serialized_end=401
  _globals['_RESOURCELIST']._serialized_start=403
  _globals['_RESOURCELIST']._serialized_end=446
  _globals['_RESOURCEREQUIREMENTS']._serialized_start=449
  _globals['_RESOURCEREQUIREMENTS']._serialized_end=581
  _globals['_HTTPPROBE']._serialized_start=583
  _globals['_HTTPPROBE']._serialized_end=648
  _globals['_CMDPROBE']._serialized_start=650
  _globals['_CMDPROBE']._serialized_end=677
  _globals['_TCPPROBE']._serialized_start=679
  _globals['_TCPPROBE']._serialized_end=730
  _globals['_HEALTHCHECK']._serialized_start=733
  _globals['_HEALTHCHECK']._serialized_end=1001
  _globals['_IMAGEREGISTRYINFO']._serialized_start=1003
  _globals['_IMAGEREGISTRYINFO']._serialized_end=1116
  _globals['_IMAGEDETAILS']._serialized_start=1118
  _globals['_IMAGEDETAILS']._serialized_end=1237
  _globals['_PROGRAMCONFIG']._serialized_start=1240
  _globals['_PROGRAMCONFIG']._serialized_end=1892
  _globals['_PROGRAMCONFIG_ENVENTRY']._serialized_start=1802
  _globals['_PROGRAMCONFIG_ENVENTRY']._serialized_end=1878
  _globals['_PERRELEASECHANNELPROGRAMCONFIG']._serialized_start=1895
  _globals['_PERRELEASECHANNELPROGRAMCONFIG']._serialized_end=2289
  _globals['_PERRELEASECHANNELPROGRAMCONFIG_ENVENTRY']._serialized_start=1802
  _globals['_PERRELEASECHANNELPROGRAMCONFIG_ENVENTRY']._serialized_end=1878
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import collections.abc
import grpc
import prodvana.proto.prodvana.deployment.manager_pb2

class DeploymentManagerStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    RecordDeployment: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.deployment.manager_pb2.RecordDeploymentReq,
        prodvana.proto.prodvana.deployment.manager_pb2.RecordDeploymentResp,
    ]
    UpdateDeploymentStatus: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.deployment.manager_pb2.UpdateDeploymentStatusReq,
        prodvana.proto.prodvana.deployment.manager_pb2.UpdateDeploymentStatusResp,
    ]
    ListDeployments: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.deployment.manager_pb2.ListDeploymentsReq,
        prodvana.proto.prodvana.deployment.manager_pb2.ListDeploymentsResp,
    ]
    ListDeploymentsStream: grpc.UnaryStreamMultiCallable[
        prodvana.proto.prodvana.deployment.manager_pb2.ListDeploymentsReq,
        prodvana.proto.prodvana.deployment.manager_pb2.ListDeploymentsResp,
    ]
    """page tokens arguments are ignored here"""
    CompareDeployment: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.deployment.manager_pb2.CompareDeploymentReq,
        prodvana.proto.prodvana.deployment.manager_pb2.CompareDeploymentResp,
    ]
    PreviewDeployment: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.deployment.manager_pb2.PreviewDeploymentReq,
        prodvana.proto.prodvana.deployment.manager_pb2.PreviewDeploymentResp,
    ]
    GetLatestDeployments: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.deployment.manager_pb2.GetLatestDeploymentsReq,
        prodvana.proto.prodvana.deployment.manager_pb2.GetLatestDeploymentsResp,
    ]
    """returns the latest deployments for each (application, service, deployment channel) tuple."""
    CheckCommitInDeployment: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.deployment.manager_pb2.CheckCommitInDeploymentReq,
        prodvana.proto.prodvana.deployment.manager_pb2.CheckCommitInDeploymentResp,
    ]

class DeploymentManagerServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def RecordDeployment(
        self,
        request: prodvana.proto.prodvana.deployment.manager_pb2.RecordDeploymentReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.deployment.manager_pb2.RecordDeploymentResp: ...
    @abc.abstractmethod
    def UpdateDeploymentStatus(
        self,
        request: prodvana.proto.prodvana.deployment.manager_pb2.UpdateDeploymentStatusReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.deployment.manager_pb2.UpdateDeploymentStatusResp: ...
    @abc.abstractmethod
    def ListDeployments(
        self,
        request: prodvana.proto.prodvana.deployment.manager_pb2.ListDeploymentsReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.deployment.manager_pb2.ListDeploymentsResp: ...
    @abc.abstractmethod
    def ListDeploymentsStream(
        self,
        request: prodvana.proto.prodvana.deployment.manager_pb2.ListDeploymentsReq,
        context: grpc.ServicerContext,
    ) -> collections.abc.Iterator[prodvana.proto.prodvana.deployment.manager_pb2.ListDeploymentsResp]:
        """page tokens arguments are ignored here"""
    @abc.abstractmethod
    def CompareDeployment(
        self,
        request: prodvana.proto.prodvana.deployment.manager_pb2.CompareDeploymentReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.deployment.manager_pb2.CompareDeploymentResp: ...
    @abc.abstractmethod
    def PreviewDeployment(
        self,
        request: prodvana.proto.prodvana.deployment.manager_pb2.PreviewDeploymentReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.deployment.manager_pb2.PreviewDeploymentResp: ...
    @abc.abstractmethod
    def GetLatestDeployments(
        self,
        request: prodvana.proto.prodvana.deployment.manager_pb2.GetLatestDeploymentsReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.deployment.manager_pb2.GetLatestDeploymentsResp:
        """returns the latest deployments for each (application, service, deployment channel) tuple."""
    @abc.abstractmethod
    def CheckCommitInDeployment(
        self,
        request: prodvana.proto.prodvana.deployment.manager_pb2.CheckCommitInDeploymentReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.deployment.manager_pb2.CheckCommitInDeploymentResp: ...

def add_DeploymentManagerServicer_to_server(servicer: DeploymentManagerServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.message
import prodvana.proto.prodvana.common_config.notification_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Notification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_OVERRIDE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    @property
    def config_override(self) -> prodvana.proto.prodvana.common_config.notification_pb2.NotificationConfig:
        """will default to application's notification config"""
    message: builtins.str
    def __init__(
        self,
        *,
        config_override: prodvana.proto.prodvana.common_config.notification_pb2.NotificationConfig | None = ...,
        message: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config_override", b"config_override"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config_override", b"config_override", "message", b"message"]) -> None: ...

global___Notification = Notification

class RetryConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_RETRY_DURATION_FIELD_NUMBER: builtins.int
    RETRY_FOREVER_FIELD_NUMBER: builtins.int
    FIRST_FAILURE_NOTIFICATION_FIELD_NUMBER: builtins.int
    @property
    def max_retry_duration(self) -> google.protobuf.duration_pb2.Duration: ...
    retry_forever: builtins.bool
    @property
    def first_failure_notification(self) -> global___Notification: ...
    def __init__(
        self,
        *,
        max_retry_duration: google.protobuf.duration_pb2.Duration | None = ...,
        retry_forever: builtins.bool = ...,
        first_failure_notification: global___Notification | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["first_failure_notification", b"first_failure_notification", "limit", b"limit", "max_retry_duration", b"max_retry_duration", "retry_forever", b"retry_forever"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["first_failure_notification", b"first_failure_notification", "limit", b"limit", "max_retry_duration", b"max_retry_duration", "retry_forever", b"retry_forever"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["limit", b"limit"]) -> typing_extensions.Literal["max_retry_duration", "retry_forever"] | None: ...

global___RetryConfig = RetryConfig



import os
from typing import Callable

from prodvana.client import Client
from prodvana.proto.prodvana.desired_state.manager_pb2 import GetDesiredStateReq
from prodvana.proto.prodvana.service.service_config_pb2 import (
    CompiledServiceInstanceConfig,
)
from prodvana.proto.prodvana.service.service_manager_pb2 import (
    GetMaterializedConfigReq,
    GetServiceInstanceReq,
)


class InjectedVariables:
    PVN_APPLICATION = "PVN_APPLICATION"
    PVN_RELEASE_CHANNEL = "PVN_RELEASE_CHANNEL"
    PVN_SERVICE = "PVN_SERVICE"
    PVN_DESIRED_STATE_ID = "PVN_DESIRED_STATE_ID"


def must_get_env(key: str, msg: str) -> str:
    val = os.getenv(key)
    assert val, f"{key} not set. {msg}"
    return val


def service_config_protection(
    client: Client, check: Callable[[CompiledServiceInstanceConfig], None]
) -> None:
    """
    A protection that is meant to run at the service or convergence level.
    `check` is a function that should throw an exception if there is something wrong with the service configuration.
    At the service level, check is called with the current service configuration.
    At the convergence level, check is called with the incoming service configuration.
    """
    app = must_get_env(
        InjectedVariables.PVN_APPLICATION,
        "Only service-instance-level protections are supported",
    )
    rc = must_get_env(
        InjectedVariables.PVN_RELEASE_CHANNEL,
        "Only service-instance-level protections are supported",
    )
    svc = must_get_env(
        InjectedVariables.PVN_SERVICE,
        "Only service-instance-level protections are supported",
    )
    root_ds_id = os.getenv(InjectedVariables.PVN_DESIRED_STATE_ID)
    if root_ds_id:
        # convergence level
        ds_resp = client.desired_state_manager.GetDesiredState(
            GetDesiredStateReq(
                desired_state_id=root_ds_id,
            )
        )
        assert ds_resp.compiled_desired_state.service, "Desired State is not a Service"
        assert ds_resp.compiled_desired_state.service.application == app, (
            f"Desired State is for application {ds_resp.compiled_desired_state.service.application}, "
            f"but protection is for {app}"
        )
        assert ds_resp.compiled_desired_state.service.service == svc, (
            f"Desired State is for service {ds_resp.compiled_desired_state.service.service}, "
            f"but protection is for {svc}"
        )
        for inst in ds_resp.compiled_desired_state.service.release_channels:
            if inst.release_channel == rc:
                version = inst.versions[0].version
                cfg_resp = client.service_manager.GetMaterializedConfig(
                    GetMaterializedConfigReq(
                        application=app,
                        service=svc,
                        version=version,
                    )
                )
                for inst_cfg in cfg_resp.compiled_service_instance_configs:
                    if inst_cfg.release_channel == rc:
                        check(inst_cfg)
                        return
                assert (
                    False
                ), f"Could not find service instance cfg for {app}/{rc}/{svc} at version {version}"
        assert False, f"Could not find service instance {app}/{rc}/{svc}"

    # service-instance level
    inst_resp = client.service_manager.GetServiceInstance(
        GetServiceInstanceReq(
            application=app,
            release_channel=rc,
            service=svc,
        )
    )
    check(inst_resp.service_instance.config)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ConfigureK8sClusterReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class GcpOptions(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PROJECT_FIELD_NUMBER: builtins.int
        CREDENTIALS_FIELD_NUMBER: builtins.int
        project: builtins.str
        credentials: builtins.str
        """TODO(naphat) there should be an integrations table for this and elevate to top level data model"""
        def __init__(
            self,
            *,
            project: builtins.str = ...,
            credentials: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["credentials", b"credentials", "project", b"project"]) -> None: ...

    class EKSOptions(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ACCESS_KEY_FIELD_NUMBER: builtins.int
        SECRET_KEY_FIELD_NUMBER: builtins.int
        ACCOUNT_ID_FIELD_NUMBER: builtins.int
        ROLE_ARN_FIELD_NUMBER: builtins.int
        access_key: builtins.str
        secret_key: builtins.str
        account_id: builtins.str
        role_arn: builtins.str
        def __init__(
            self,
            *,
            access_key: builtins.str = ...,
            secret_key: builtins.str = ...,
            account_id: builtins.str = ...,
            role_arn: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["access_key", b"access_key", "account_id", b"account_id", "role_arn", b"role_arn", "secret_key", b"secret_key"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    GCP_OPTIONS_FIELD_NUMBER: builtins.int
    EKS_OPTIONS_FIELD_NUMBER: builtins.int
    INSTANCE_TYPE_FIELD_NUMBER: builtins.int
    NODEPOOL_ZONES_FIELD_NUMBER: builtins.int
    NODE_COUNT_PER_ZONE_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def gcp_options(self) -> global___ConfigureK8sClusterReq.GcpOptions: ...
    @property
    def eks_options(self) -> global___ConfigureK8sClusterReq.EKSOptions: ...
    instance_type: builtins.str
    @property
    def nodepool_zones(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    node_count_per_zone: builtins.int
    region: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        gcp_options: global___ConfigureK8sClusterReq.GcpOptions | None = ...,
        eks_options: global___ConfigureK8sClusterReq.EKSOptions | None = ...,
        instance_type: builtins.str = ...,
        nodepool_zones: collections.abc.Iterable[builtins.str] | None = ...,
        node_count_per_zone: builtins.int = ...,
        region: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloud_provider_oneof", b"cloud_provider_oneof", "eks_options", b"eks_options", "gcp_options", b"gcp_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_provider_oneof", b"cloud_provider_oneof", "eks_options", b"eks_options", "gcp_options", b"gcp_options", "instance_type", b"instance_type", "name", b"name", "node_count_per_zone", b"node_count_per_zone", "nodepool_zones", b"nodepool_zones", "region", b"region"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["cloud_provider_oneof", b"cloud_provider_oneof"]) -> typing_extensions.Literal["gcp_options", "eks_options"] | None: ...

global___ConfigureK8sClusterReq = ConfigureK8sClusterReq

class ConfigureK8sClusterResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    RUN_ID_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    ARCHIVE_URL_FIELD_NUMBER: builtins.int
    id: builtins.str
    @property
    def run_id(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    version: builtins.str
    archive_url: builtins.str
    """TODO(naphat) delete archive_url once we automate pulumi runs"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        run_id: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        version: builtins.str = ...,
        archive_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["run_id", b"run_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["archive_url", b"archive_url", "id", b"id", "run_id", b"run_id", "version", b"version"]) -> None: ...

global___ConfigureK8sClusterResp = ConfigureK8sClusterResp

class ManagedResource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Run(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        VERSION_FIELD_NUMBER: builtins.int
        STATE_FIELD_NUMBER: builtins.int
        TERMINAL_FIELD_NUMBER: builtins.int
        CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
        LAST_UPDATE_TIMESTAMP_FIELD_NUMBER: builtins.int
        MESSAGE_FIELD_NUMBER: builtins.int
        version: builtins.str
        state: builtins.str
        terminal: builtins.bool
        @property
        def creation_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        @property
        def last_update_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        message: builtins.str
        def __init__(
            self,
            *,
            version: builtins.str = ...,
            state: builtins.str = ...,
            terminal: builtins.bool = ...,
            creation_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
            last_update_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
            message: builtins.str = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "last_update_timestamp", b"last_update_timestamp"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "last_update_timestamp", b"last_update_timestamp", "message", b"message", "state", b"state", "terminal", b"terminal", "version", b"version"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    LATEST_RUN_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    type: builtins.str
    @property
    def latest_run(self) -> global___ManagedResource.Run: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        type: builtins.str = ...,
        latest_run: global___ManagedResource.Run | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["latest_run", b"latest_run"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "latest_run", b"latest_run", "name", b"name", "type", b"type"]) -> None: ...

global___ManagedResource = ManagedResource

class GetManagedResourceReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MANAGED_RESOURCE_FIELD_NUMBER: builtins.int
    managed_resource: builtins.str
    def __init__(
        self,
        *,
        managed_resource: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["managed_resource", b"managed_resource"]) -> None: ...

global___GetManagedResourceReq = GetManagedResourceReq

class GetManagedResourceResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MANAGED_RESOURCE_FIELD_NUMBER: builtins.int
    @property
    def managed_resource(self) -> global___ManagedResource: ...
    def __init__(
        self,
        *,
        managed_resource: global___ManagedResource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["managed_resource", b"managed_resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["managed_resource", b"managed_resource"]) -> None: ...

global___GetManagedResourceResp = GetManagedResourceResp

class ListManagedResourcesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListManagedResourcesReq = ListManagedResourcesReq

class ListManagedResourcesResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MANAGED_RESOURCES_FIELD_NUMBER: builtins.int
    @property
    def managed_resources(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ManagedResource]: ...
    def __init__(
        self,
        *,
        managed_resources: collections.abc.Iterable[global___ManagedResource] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["managed_resources", b"managed_resources"]) -> None: ...

global___ListManagedResourcesResp = ListManagedResourcesResp

class GetArchiveReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MANAGED_RESOURCE_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    managed_resource: builtins.str
    version: builtins.str
    """default to latest version"""
    def __init__(
        self,
        *,
        managed_resource: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["managed_resource", b"managed_resource", "version", b"version"]) -> None: ...

global___GetArchiveReq = GetArchiveReq

class GetArchiveResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BYTES_FIELD_NUMBER: builtins.int
    bytes: builtins.bytes
    def __init__(
        self,
        *,
        bytes: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bytes", b"bytes"]) -> None: ...

global___GetArchiveResp = GetArchiveResp

class MarkRunDoneReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MANAGED_RESOURCE_FIELD_NUMBER: builtins.int
    RUN_ID_FIELD_NUMBER: builtins.int
    SUCCEEDED_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    managed_resource: builtins.str
    @property
    def run_id(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    succeeded: builtins.bool
    msg: builtins.str
    def __init__(
        self,
        *,
        managed_resource: builtins.str = ...,
        run_id: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        succeeded: builtins.bool = ...,
        msg: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["run_id", b"run_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["managed_resource", b"managed_resource", "msg", b"msg", "run_id", b"run_id", "succeeded", b"succeeded"]) -> None: ...

global___MarkRunDoneReq = MarkRunDoneReq

class MarkRunDoneResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MarkRunDoneResp = MarkRunDoneResp

class DeleteManagedResourceReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MANAGED_RESOURCE_FIELD_NUMBER: builtins.int
    managed_resource: builtins.str
    def __init__(
        self,
        *,
        managed_resource: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["managed_resource", b"managed_resource"]) -> None: ...

global___DeleteManagedResourceReq = DeleteManagedResourceReq

class DeleteManagedResourceResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    RUN_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """resource ID and run ID, which can be used in conjunction with GetManagedResource to track
    status of deletion.
    """
    @property
    def run_id(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        run_id: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["run_id", b"run_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "run_id", b"run_id"]) -> None: ...

global___DeleteManagedResourceResp = DeleteManagedResourceResp



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/links.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"prodvana/common_config/links.proto\x12\x16prodvana.common_config\x1a\x17validate/validate.proto\";\n\x04Link\x12\x14\n\x03url\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1d\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42RZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.common_config.links_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _LINK.fields_by_name['url']._options = None
  _LINK.fields_by_name['url']._serialized_options = b'\372B\004r\002\020\001'
  _LINK.fields_by_name['display_name']._options = None
  _LINK.fields_by_name['display_name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_LINK']._serialized_start=87
  _globals['_LINK']._serialized_end=146
# @@protoc_insertion_point(module_scope)
